==> sapdb-all-linux-32bit-i386-7_3_0_48.tgz: env/ORADD.py <==
#
# =====================================================
# @(#) ORADD                     7.2        1999-07-29
# =====================================================
# Changes in  7.2:
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


from installib import *

def install (session,options):
    """Installing system tables for ORACLE (V7) mode
    """

    repmanCmd (session, 'INSTALLATION ON')

    repmanCmd (session, 'AUTOCOMMIT OFF')

    if not sqlOK (session, """
            SELECT username FROM sysdd.users
             WHERE username = UPPER('sys')"""):
        stopIfSqlNotOK (session, 'CREATE USER sys PASSWORD sys DBA')
        repmanCmd (session, 'COMMIT')
    else:
        stopIfSqlNotOK (session, 'ALTER PASSWORD sys sys')


    if sqlOK (session, """SELECT username FROM sysdd.users
             WHERE username = 'PUBLIC'"""):
        stopIfSqlNotOK (session, 'DROP USER "PUBLIC" CASCADE')

    repmanCmd (session, 'SQLMODE INTERNAL')

    switchToDefaultUser (session, options)

    # The creation of the Oracle system tables, the synonyms for them
    # and the comments on it

    include (session, options,
        "ORADDV",
        "ORADDSYN",
        "ORADDCOM"
        )


    repmanCmd (session, 'COMMIT')

    repmanCmd (session, 'INSTALLATION OFF')

    # End of Install


if __name__ == '__main__':
    connectAndInstall (install, install.__doc__)

==> sapdb-all-linux-32bit-i386-7_4_3_32.tgz: env/ORADD.py <==
#
# =====================================================
# @(#) ORADD                     7.2        1999-07-29
# =====================================================
# Changes in  7.2:
#
#    ========== licence begin LGPL
#    Copyright (C) 2000 SAP AG
#
#    This library is free software; you can redistribute it and/or
#    modify it under the terms of the GNU Lesser General Public
#    License as published by the Free Software Foundation; either
#    version 2.1 of the License, or (at your option) any later version.
#
#    This library is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
#    Lesser General Public License for more details.
#
#    You should have received a copy of the GNU Lesser General Public
#    License along with this library; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    ========== licence end
#


from installib import *

def install (session,options):
    """Installing system tables for ORACLE (V7) mode
    """

    loaderCmd (session, 'INSTALLATION ON')

    loaderCmd (session, 'AUTOCOMMIT OFF')

    if not sqlOK (session, """
            SELECT username FROM sysdd.users
             WHERE username = UPPER('sys')"""):
        stopIfSqlNotOK (session, 'CREATE USER sys PASSWORD sys DBA NOT EXCLUSIVE')
        loaderCmd (session, 'COMMIT')
    else:
        stopIfSqlNotOK (session, 'ALTER PASSWORD sys sys')


    if sqlOK (session, """SELECT username FROM sysdd.users
             WHERE username = 'PUBLIC'"""):
        stopIfSqlNotOK (session, 'DROP USER "PUBLIC" CASCADE')

    loaderCmd (session, 'SQLMODE INTERNAL')

    switchToDefaultUser (session, options)

    # The creation of the Oracle system tables, the synonyms for them
    # and the comments on it

    include (session, options,
        "ORADDV",
        "ORADDSYN",
        "ORADDCOM"
        )


    loaderCmd (session, 'COMMIT')

    loaderCmd (session, 'INSTALLATION OFF')

    # End of Install


if __name__ == '__main__':
    connectAndInstall (install, install.__doc__)
